summaryrefslogtreecommitdiff
path: root/compiler/typecheck/Inst.hs
diff options
context:
space:
mode:
Diffstat (limited to 'compiler/typecheck/Inst.hs')
-rw-r--r--compiler/typecheck/Inst.hs22
1 files changed, 11 insertions, 11 deletions
diff --git a/compiler/typecheck/Inst.hs b/compiler/typecheck/Inst.hs
index 96b387b7ec..741be62e03 100644
--- a/compiler/typecheck/Inst.hs
+++ b/compiler/typecheck/Inst.hs
@@ -46,27 +46,27 @@ import GHC.Hs
import TcHsSyn
import TcRnMonad
import Constraint
-import Predicate
+import GHC.Core.Predicate
import TcOrigin
import TcEnv
import TcEvidence
-import InstEnv
+import GHC.Core.InstEnv
import TysWiredIn ( heqDataCon, eqDataCon )
import GHC.Core ( isOrphan )
import FunDeps
import TcMType
-import Type
-import TyCoRep
-import TyCoPpr ( debugPprType )
+import GHC.Core.Type
+import GHC.Core.TyCo.Rep
+import GHC.Core.TyCo.Ppr ( debugPprType )
import TcType
import GHC.Driver.Types
-import Class( Class )
+import GHC.Core.Class( Class )
import MkId( mkDictFunId )
import GHC.Core( Expr(..) ) -- For the Coercion constructor
import Id
import Name
import Var ( EvVar, tyVarName, VarBndr(..) )
-import DataCon
+import GHC.Core.DataCon
import VarEnv
import PrelNames
import SrcLoc
@@ -385,7 +385,7 @@ instCallConstraints orig preds
instDFunType :: DFunId -> [DFunInstType]
-> TcM ( [TcType] -- instantiated argument types
, TcThetaType ) -- instantiated constraint
--- See Note [DFunInstType: instantiating types] in InstEnv
+-- See Note [DFunInstType: instantiating types] in GHC.Core.InstEnv
instDFunType dfun_id dfun_inst_tys
= do { (subst, inst_tys) <- go empty_subst dfun_tvs dfun_inst_tys
; return (inst_tys, substTheta subst dfun_theta) }
@@ -454,14 +454,14 @@ tcInstInvisibleTyBinder subst (Named (Bndr tv _))
tcInstInvisibleTyBinder subst (Anon af ty)
| Just (mk, k1, k2) <- get_eq_tys_maybe (substTy subst ty)
-- Equality is the *only* constraint currently handled in types.
- -- See Note [Constraints in kinds] in TyCoRep
+ -- See Note [Constraints in kinds] in GHC.Core.TyCo.Rep
= ASSERT( af == InvisArg )
do { co <- unifyKind Nothing k1 k2
; arg' <- mk co
; return (subst, arg') }
| otherwise -- This should never happen
- -- See TyCoRep Note [Constraints in kinds]
+ -- See GHC.Core.TyCo.Rep Note [Constraints in kinds]
= pprPanic "tcInvisibleTyBinder" (ppr ty)
-------------------------------
@@ -472,7 +472,7 @@ get_eq_tys_maybe :: Type
, Type -- t1
, Type -- t2
)
--- See Note [Constraints in kinds] in TyCoRep
+-- See Note [Constraints in kinds] in GHC.Core.TyCo.Rep
get_eq_tys_maybe ty
-- Lifted heterogeneous equality (~~)
| Just (tc, [_, _, k1, k2]) <- splitTyConApp_maybe ty